==> igniteui-webcomponents-core-3.2.4.tgz: package/esm2015/lib/ToolCommandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolCommandDescription } from "./ToolCommandDescription";
/**
 * @hidden
 */
export let ToolCommandDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolCommandDescriptionMetadata extends Base {
        static b(a) {
            if (ToolCommandDescriptionMetadata.a == null) {
                ToolCommandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolCommandDescriptionMetadata.c(ToolCommandDescriptionMetadata.a);
            }
            if (a.g(ToolCommandDescriptionMetadata.a)) {
                return;
            }
            a.s(ToolCommandDescriptionMetadata.a);
        }
        static c(a) {
            a.item("CommandId", "String");
            a.item("ArgumentsList", "Collection:ToolCommandArgument:ToolCommandArgumentCollection:ToolCommandArgument");
        }
        static d(a) {
            ToolCommandDescriptionMetadata.b(a);
            a.u("ToolCommand", () => new ToolCommandDescription());
            a.t("ToolCommand", ToolCommandDescriptionMetadata.a);
        }
    }
    ToolCommandDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolCommandDescriptionMetadata, 'ToolCommandDescriptionMetadata');
    ToolCommandDescriptionMetadata.a = null;
    return ToolCommandDescriptionMetadata;
})();

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ToolCommandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolCommandDescription } from "./ToolCommandDescription";
/**
 * @hidden
 */
export let ToolCommandDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolCommandDescriptionMetadata extends Base {
        static b(a) {
            if (ToolCommandDescriptionMetadata.a == null) {
                ToolCommandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolCommandDescriptionMetadata.c(ToolCommandDescriptionMetadata.a);
            }
            if (a.j(ToolCommandDescriptionMetadata.a)) {
                return;
            }
            a.y(ToolCommandDescriptionMetadata.a);
        }
        static c(a) {
            a.item("CommandId", "String");
            a.item("ArgumentsList", "Collection:ToolCommandArgument:ToolCommandArgumentCollection:ToolCommandArgument");
        }
        static d(a) {
            ToolCommandDescriptionMetadata.b(a);
            a.aa("ToolCommand", () => new ToolCommandDescription());
            a.z("ToolCommand", ToolCommandDescriptionMetadata.a);
        }
    }
    ToolCommandDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolCommandDescriptionMetadata, 'ToolCommandDescriptionMetadata');
    ToolCommandDescriptionMetadata.a = null;
    return ToolCommandDescriptionMetadata;
})();
